local OrgCreateMountSection = STATS.CreateMountSection
STATS.CreateMountSection = function(self,...)
	OrgCreateMountSection(self,...)
	
	self:AddDivider()
	self:AddHeader(SI_STABLE_STABLED_MOUNTS_HEADER)
	
	local stable = WINDOW_MANAGER:CreateControl("HarvensStable", self.scrollChild, CT_CONTROL)
	stable:SetDimensions(607, 55)
	stable:SetHidden(false)
	self:AddRawControl(stable)
	
	local stableSlots = {}
	
	for i=1, GetMaxStableSlots() do
		local stableSlot = WINDOW_MANAGER:CreateControlFromVirtual("HarvensStabledMounts"..i, stable, "ZO_StatsStableSlotRow")
		stableSlot:SetHidden(true)
		stableSlot:SetHandler("OnMouseEnter", function(control)
			if not control.empty then
				InitializeTooltip(ItemTooltip, control, RIGHT, -15)
				ItemTooltip:SetMount(ACTIVE_MOUNT_INDEX+i)
				ItemTooltip:AddVerticalPadding(5)
				ItemTooltip:AddLine(stableSlots[i].description, "", ZO_TOOLTIP_DEFAULT_COLOR:UnpackRGB())
			end
		end)
		table.insert(stableSlots, stableSlot)
	end
	
	local function OnUpdate(stableSlot, stableIndex)
        if not stableSlot.empty then
            local timeUntilCanBeFed = GetTimeUntilMountCanBeFed(stableIndex)
            local canBeFed = timeUntilCanBeFed ~= nil and timeUntilCanBeFed == 0

            if canBeFed then
                stableSlot.readyForFeed:SetHidden(timeUntilCanBeFed == nil)
                stableSlot.timer:SetHidden(true)
                stableSlot:SetHandler("OnUpdate", nil)
            else
                stableSlot.readyForFeed:SetHidden(true)

                if timeUntilCanBeFed == nil then
                    stableSlot.timer:SetHidden(true)
                else
                    stableSlot.timer:SetHidden(false)
                    if stableSlot.timer.mouseInside then
                        local timeLeft = ZO_FormatTimeMilliseconds(timeUntilCanBeFed, TIME_FORMAT_STYLE_COLONS, TIME_FORMAT_PRECISION_TWELVE_HOUR)
                        InformationTooltip:ClearLines()
                        SetTooltipText(InformationTooltip, zo_strformat(SI_STABLE_MOUNT_NOT_HUNGRY, timeLeft))
                    end
                end
            end
        else
            stableSlot.readyForFeed:SetHidden(true)
            stableSlot.timer:SetHidden(true)
            stableSlot:SetHandler("OnUpdate", nil)
        end
	end
	
	local function UpdateStabledMounts()
		local numActive = -1
		local lastControl = nil
		for i=1, #stableSlots do
			stableSlots[i]:ClearAnchors()
			if IsStableSlotEmpty(ACTIVE_MOUNT_INDEX+i) then
				stableSlots[i]:SetHidden(true)
				stableSlots[i].empty = true
				stableSlots[i]:SetHandler("OnUpdate", nil)
			else
				stableSlots[i]:SetHidden(false)
				if not lastControl then
					stableSlots[i]:SetAnchor(TOP, stable, TOP, 0, 5)
				else
					stableSlots[i]:SetAnchor(TOP, lastControl, BOTTOM, 0, 5)
				end
				stableSlots[i].empty = false
				lastControl = stableSlots[i]
				numActive = numActive + 1
				
				local name, icon, portrait, breed, description = GetStableSlotInfo(ACTIVE_MOUNT_INDEX+i)
	            stableSlots[i].name:SetText(name)
	            stableSlots[i].description = description
	            stableSlots[i].breed:SetText(zo_strformat(SI_MOUNT_BREED_FORMAT, breed))
	            stableSlots[i].icon:SetHidden(false)
	            stableSlots[i].icon:SetTexture(icon)
	            
	            local timeUntilCanBeFed, totalFeedWaitDuration = GetTimeUntilMountCanBeFed(ACTIVE_MOUNT_INDEX+i)
	            if timeUntilCanBeFed and timeUntilCanBeFed > 0 then
	                stableSlots[i].timer:SetHidden(false)
	                stableSlots[i].timerOverlay:StartCooldown(timeUntilCanBeFed, totalFeedWaitDuration, CD_TYPE_RADIAL, CD_TIME_TYPE_TIME_UNTIL, NO_LEADING_EDGE)
	            else
	                stableSlots[i].timer:SetHidden(true)
	            end
	            
	            stableSlots[i]:SetHandler("OnUpdate", function() OnUpdate(stableSlots[i], ACTIVE_MOUNT_INDEX+i) end)
			end
		end
		
		stable:SetHeight(55 + (numActive > 0 and numActive*55 or 0))
		
		if not lastControl then
			stableSlots[1]:SetHidden(false)
			stableSlots[1].icon:SetHidden(true)
			stableSlots[1]:SetAnchor(TOP, stable, TOP, 0, 5)
			stableSlots[1].name:SetText(GetString(SI_MOUNT_NONE_ACTIVE))
			stableSlots[1].breed:SetText("")
			stableSlots[1].timer:SetHidden(true)
			stableSlots[1].readyForFeed:SetHidden(true)
		end
	end
	
	UpdateStabledMounts()
	
	EVENT_MANAGER:RegisterForEvent("HarvensStabledMounts", EVENT_MOUNTS_FULL_UPDATE, UpdateStabledMounts)
	EVENT_MANAGER:RegisterForEvent("HarvensStabledMounts", EVENT_MOUNT_UPDATE, UpdateStabledMounts)
	EVENT_MANAGER:RegisterForEvent("HarvensStabledMounts", EVENT_MOUNT_ADDED_TO_STABLE, UpdateStabledMounts)
end